@@ -1,21 +1,22 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
 use crate::ffi::orjson_fragmenttype_new;
+use core::ffi::c_char;
+#[cfg(feature = "yyjson")]
+use core::ffi::c_void;
+#[cfg(feature = "yyjson")]
+use core::mem::MaybeUninit;
+use core::ptr::{null_mut, NonNull};
 use once_cell::race::{OnceBool, OnceBox};
 use pyo3_ffi::*;
 #[cfg(feature = "yyjson")]
 use std::cell::UnsafeCell;
-#[cfg(feature = "yyjson")]
-use std::mem::MaybeUninit;
-use std::os::raw::c_char;
-#[cfg(feature = "yyjson")]
-use std::os::raw::c_void;
-use std::ptr::{null_mut, NonNull};
 
 pub struct NumpyTypes {
     pub array: *mut PyTypeObject,
     pub float64: *mut PyTypeObject,
     pub float32: *mut PyTypeObject,
+    pub float16: *mut PyTypeObject,
     pub int64: *mut PyTypeObject,
     pub int32: *mut PyTypeObject,
     pub int16: *mut PyTypeObject,
@@ -135,6 +136,7 @@ pub fn init_typerefs() {
 fn _init_typerefs_impl() -> bool {
     unsafe {
         debug_assert!(crate::opt::MAX_OPT < u16::MAX as i32);
+
         assert!(crate::deserialize::KEY_MAP
             .set(crate::deserialize::KeyMap::default())
             .is_ok());
@@ -238,6 +240,7 @@ pub fn load_numpy_types() -> Box<Option<NonNull<NumpyTypes>>> {
         let numpy_module_dict = PyObject_GenericGetDict(numpy, null_mut());
         let types = Box::new(NumpyTypes {
             array: look_up_numpy_type(numpy_module_dict, "ndarray\0"),
+            float16: look_up_numpy_type(numpy_module_dict, "half\0"),
             float32: look_up_numpy_type(numpy_module_dict, "float32\0"),
             float64: look_up_numpy_type(numpy_module_dict, "float64\0"),
             int8: look_up_numpy_type(numpy_module_dict, "int8\0"),
